Commands

Enum Commands 

pub enum Commands {
Show 17 variants New { domain: String, path: String, }, Ssg { ssg: Ssg, }, Build { ignore_cache: bool, }, Start { app_api: AppApi, global_args: GlobalArgs, disable_defaults: bool, }, Publish { tls_staging: bool, }, Templates { templates: Templates, }, Content { content: Content, }, Assets { assets: Assets, }, Models { models: Models, }, Actions { actions: Actions, }, Integrations { integrations: Integrations, }, Accounts { accounts: Accounts, }, App { app: App, }, Secrets { secrets: Secrets, }, Root { root: Root, }, Doctor { fix: Option<Vec<Fix>>, }, Utils { utils: Utils, },
}

Variants



New

create a new Ordinary project

Fields

domain: String

project domain

path: String

project path



Ssg

manage static site configuration

Fields

ssg: Ssg


Build

build your Ordinary project

Note: will load environment variables from .env

Fields

ignore_cache: bool

build project without checking the cache



Start

start the app, locally

Fields

app_api: AppApi
global_args: GlobalArgs
disable_defaults: bool

disables these defaults set for development: --stdio-logs --stdio-logs-fmt concise --insecure --insecure-cookies



Publish

combines build, content update, assets write, templates upload, actions install

Fields

tls_staging: bool

overrides if mode=production. does nothing if mode is localhost or staging

useful for when you’re validating that your DNS is configured properly, and you want to avoid the Let’s Encrypt rate limit for production mode https://letsencrypt.org/docs/rate-limits/



Templates

manage templates in your Ordinary project

Fields

templates: Templates


Content

manage content in your Ordinary project

Fields

content: Content


Assets

manage assets in your Ordinary project

Fields

assets: Assets


Models

manage models in your Ordinary project

Fields

models: Models


Actions

manage actions in your Ordinary project

Fields

actions: Actions


Integrations

manage integrations in your Ordinary project

Fields

integrations: Integrations


Accounts

manage accounts connected to ordinaryd

Fields

accounts: Accounts


App

manage applications running on ordinaryd

Fields

app: App


Secrets

manage secrets in your Ordinary application

Fields

secrets: Secrets


Root

Fields

root: Root


Doctor

ensure that all the correct system components are installed

Fields

fix: Option<Vec<Fix>>

auto fix installs



Utils

utility functions for aiding project development

Fields

utils: Utils