pub enum Commands {
Show 17 variants
New {
domain: String,
path: String,
},
Ssg {
ssg: Ssg,
},
Build {
ignore_cache: bool,
},
Start {
app_api: AppApi,
global_args: GlobalArgs,
disable_defaults: bool,
},
Publish {
tls_staging: bool,
},
Templates {
templates: Templates,
},
Content {
content: Content,
},
Assets {
assets: Assets,
},
Models {
models: Models,
},
Actions {
actions: Actions,
},
Integrations {
integrations: Integrations,
},
Accounts {
accounts: Accounts,
},
App {
app: App,
},
Secrets {
secrets: Secrets,
},
Root {
root: Root,
},
Doctor {
fix: Option<Vec<Fix>>,
},
Utils {
utils: Utils,
},
}Variants
New
create a new Ordinary project
Ssg
manage static site configuration
Fields
ssg: SsgBuild
build your Ordinary project
Note: will load environment variables from .env
Start
start the app, locally
Fields
global_args: GlobalArgsPublish
combines build, content update, assets write,
templates upload, actions install
Fields
tls_staging: booloverrides if mode=production. does nothing if mode is localhost or staging
useful for when you’re validating that your DNS is configured properly, and you want to avoid the Let’s Encrypt rate limit for production mode https://letsencrypt.org/docs/rate-limits/
Templates
manage templates in your Ordinary project
Content
manage content in your Ordinary project
Assets
manage assets in your Ordinary project
Models
manage models in your Ordinary project
Actions
manage actions in your Ordinary project
Integrations
manage integrations in your Ordinary project
Fields
integrations: IntegrationsAccounts
manage accounts connected to ordinaryd
App
manage applications running on ordinaryd
Secrets
manage secrets in your Ordinary application
Fields
secrets: SecretsRoot
Fields
root: RootDoctor
ensure that all the correct system components are installed
Utils
utility functions for aiding project development
Fields
utils: UtilsTrait Implementations
Sourceimpl FromArgMatches for Commands
impl FromArgMatches for Commands
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Subcommand for Commands
impl Subcommand for Commands
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for Commands
impl RefUnwindSafe for Commands
impl Send for Commands
impl Sync for Commands
impl Unpin for Commands
impl UnsafeUnpin for Commands
impl UnwindSafe for Commands